@@ -22,13 +22,11 @@
  */
 
 #include <config.h>
-
+#include <gtk/gtk.h>
 #include "e-categories.h"
 
-#include "gal/util/e-i18n.h"
 #include <string.h>
 #include <gdk/gdkkeysyms.h>
-#include <libgnomeui/gnome-stock.h>
 
 #include "gal/e-table/e-table-scrolled.h"
 #include "gal/e-table/e-table.h"
@@ -545,10 +543,10 @@ e_categories_construct (ECategories *categories,
 		categories->priv->gui = gui;
 
 		gnome_dialog_append_button ( GNOME_DIALOG(categories),
-					     GNOME_STOCK_BUTTON_OK);
-	
+					     GTK_STOCK_OK);
+		
 		gnome_dialog_append_button ( GNOME_DIALOG(categories),
-					     GNOME_STOCK_BUTTON_CANCEL);
+					     GTK_STOCK_CANCEL);
 
 		gnome_dialog_set_default (GNOME_DIALOG (categories), 0);
 
@@ -559,9 +557,9 @@ e_categories_construct (ECategories *categories,
 		gtk_container_remove(GTK_CONTAINER(table->parent), table);
 		gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (categories)->vbox), table, TRUE, TRUE, 0);
 		gtk_widget_unref(table);
-		
+
 		categories->priv->entry = glade_xml_get_widget(gui, "entry-categories");
-	
+		
 		gtk_signal_connect(GTK_OBJECT(categories->priv->entry), "changed",
 				   GTK_SIGNAL_FUNC(e_categories_entry_change), categories);
 
@@ -569,7 +567,7 @@ e_categories_construct (ECategories *categories,
 		
 		gtk_signal_connect(GTK_OBJECT(button), "clicked",
 				   GTK_SIGNAL_FUNC(e_categories_button_clicked), categories);
-		
+
 		categories->priv->model = e_table_simple_new(e_categories_col_count, 
 							     e_categories_row_count,
 							     NULL,
@@ -577,10 +575,10 @@ e_categories_construct (ECategories *categories,
 							     e_categories_value_at,
 							     e_categories_set_value_at,
 							     e_categories_is_cell_editable,
-							     
+
 							     e_categories_has_save_id,
 							     e_categories_get_save_id,
-							     
+
 							     e_categories_duplicate_value,
 							     e_categories_free_value,
 							     e_categories_initialize_value,
@@ -589,7 +587,7 @@ e_categories_construct (ECategories *categories,
 							     categories);
 
 		e_table = e_table_scrolled_new (categories->priv->model, NULL, INITIAL_SPEC, NULL);
-		
+
 		categories->priv->table = e_table_scrolled_get_table(E_TABLE_SCROLLED(e_table));
 		gtk_signal_connect(GTK_OBJECT(categories->priv->table), "key_press",
 				   GTK_SIGNAL_FUNC(table_key_press), categories);
@@ -606,18 +604,18 @@ e_categories_construct (ECategories *categories,
 					  e_table, 
 					  0, 1,
 					  3, 4);
-		
+
 		gtk_widget_grab_focus (categories->priv->entry);
 		gnome_dialog_editable_enters (GNOME_DIALOG (categories), GTK_EDITABLE (categories->priv->entry));
-		
+
 		ecml = e_categories_master_list_array_new();
 		gtk_object_set (GTK_OBJECT (categories),
 				"ecml", ecml,
 				NULL);
 		gtk_object_unref(GTK_OBJECT (ecml));
-		
+
 		ec_set_categories (categories->priv->entry, initial_category_list);
-		
+
 		gtk_window_set_default_size (GTK_WINDOW (categories), 200, 400);
 	}
 }
