@@ -90,17 +90,32 @@ gtk_combo_box_finalize (GObject *object)
 {
 	GtkComboBox *combo_box = GTK_COMBO_BOX (object);
 
-	gtk_object_destroy (GTK_OBJECT (combo_box->priv->toplevel));
-	gtk_object_unref (GTK_OBJECT (combo_box->priv->toplevel));
+	g_free (combo_box->priv);
+
+	gtk_combo_box_parent_class->finalize (object);
+}
+
+static void
+gtk_combo_box_destroy (GtkObject *object)
+{
+	GtkObjectClass *klass = (GtkObjectClass *)gtk_combo_box_parent_class;
+	GtkComboBox *combo_box = GTK_COMBO_BOX (object);
+
+	if (combo_box->priv->toplevel) {
+		gtk_object_destroy (GTK_OBJECT (combo_box->priv->toplevel));
+		gtk_object_unref (GTK_OBJECT (combo_box->priv->toplevel));
+		combo_box->priv->toplevel = NULL;
+	}
+
 	if (combo_box->priv->tearoff_window) {
 		gtk_object_destroy
 			(GTK_OBJECT (combo_box->priv->tearoff_window));
 		gtk_object_unref
 			(GTK_OBJECT (combo_box->priv->tearoff_window)); /* ?? */
 	}
-	g_free (combo_box->priv);
 
-	gtk_combo_box_parent_class->finalize (object);
+	if (klass->destroy)
+                klass->destroy (object);
 }
 
 static void
@@ -109,6 +124,7 @@ gtk_combo_box_class_init (GObjectClass *object_class)
 	gtk_combo_box_parent_class = g_type_class_peek_parent (object_class);
 
 	object_class->finalize = gtk_combo_box_finalize;
+	((GtkObjectClass *)object_class)->destroy = gtk_combo_box_destroy;
 
 	gtk_combo_box_signals [POP_DOWN_WIDGET] = gtk_signal_new (
 		"pop_down_widget",
